==> members-facade-2.0.1-20200526.120707-96-sources.jar: com/bizvane/members/facade/service/inner/MemberSysService.java <==
package com.bizvane.members.facade.service.inner;

import com.bizvane.members.facade.exception.MemberException;
import com.bizvane.members.facade.models.MemberInfoModel;
import com.bizvane.members.facade.models.MembersSysModel;
import com.bizvane.members.facade.vo.MembersSysVo;
import com.bizvane.members.facade.vo.taobao.TaoBaoMemberSysRequestVo;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.SysAccountPO;

import java.util.Optional;

/**
 * @author houkai
 */
public interface MemberSysService {

    /**
     * 新建会员卡体系
     *
     * @param membersSysModel
     * @return
     * @throws MemberException
     */
    ResponseData addMemberSys(MembersSysModel membersSysModel) throws MemberException;

    /**
     * 根据品牌查询会员卡体系详情
     *
     * @param brandId
     * @return
     */
    ResponseData<MembersSysModel> queryMemberSysInfo(long brandId);

    /**
     * 编辑会员卡体系
     *
     * @param membersSysModel
     * @return
     * @throws MemberException
     */
    ResponseData updateMemberSys(MembersSysModel membersSysModel) throws MemberException;

    /**
     * 根据会员信息生成会员卡号
     *
     * @param memberInfoModel
     * @return
     */
    String produceCarNo(MemberInfoModel memberInfoModel);

    /**
     * 保存会员卡体系
     *
     * @param membersSysModel
     * @param currentUser
     * @return
     */
    ResponseData saveMemberSys(MembersSysModel membersSysModel, SysAccountPO currentUser);


    /**
     * 保存智慧门店会员体系
     */
    ResponseData<String> saveOrUpdateTaoBaoMemberSys(TaoBaoMemberSysRequestVo taoBao,Optional<SysAccountPO> optional);

    /**
     * 查询授权状态
     * @return
     */
    ResponseData<Integer> queryAuthState(Long brandId);


    /**
     * 查询会员卡体系详情
     * @param sysCompanyId
     * @param brandId
     * @return
     */
    ResponseData<MembersSysVo> queryMemberSysInfo(long sysCompanyId, long brandId);


    /**
     * 是否达到可以修改默认服务门店的最低条件
     * @param memberServiceStoreId
     * @param sysCompanyId
     * @param brandId
     * @param memberCode
     * @return
     */
    boolean canUpdateServiceStore(Long memberServiceStoreId, Long sysCompanyId, Long brandId,String memberCode);

    /**
     * 查询会员卡体系是否开启默认服务门店变更开关
     * @param sysCompanyId
     * @param brandId
     * @return
     */
    boolean isEnableChangeMbrStore(long sysCompanyId, long brandId);

    /**
     * 查询会员所属服务门店是否是会员卡体系的默认虚拟门店
     * @param memberCode
     * @param serviceStoreId
     * @param sysCompanyId
     * @param brandId
     * @return
     */
    boolean isDefaultServiceStore(String memberCode, Long serviceStoreId, Long sysCompanyId, Long brandId);
}

==> members-facade-2.0.1-20200602.034526-101-sources.jar: com/bizvane/members/facade/service/inner/MemberSysService.java <==
package com.bizvane.members.facade.service.inner;

import com.bizvane.members.facade.exception.MemberException;
import com.bizvane.members.facade.models.MemberInfoModel;
import com.bizvane.members.facade.models.MembersSysModel;
import com.bizvane.members.facade.vo.MembersSysVo;
import com.bizvane.members.facade.vo.taobao.TaoBaoMemberSysRequestVo;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.SysAccountPO;

import java.util.Optional;

/**
 * @author houkai
 */
public interface MemberSysService {

    /**
     * 新建会员卡体系
     *
     * @param membersSysModel
     * @return
     * @throws MemberException
     */
    ResponseData addMemberSys(MembersSysModel membersSysModel) throws MemberException;

    /**
     * 根据品牌查询会员卡体系详情
     *
     * @param brandId
     * @return
     */
    ResponseData<MembersSysModel> queryMemberSysInfo(long brandId);

    /**
     * 编辑会员卡体系
     *
     * @param membersSysModel
     * @return
     * @throws MemberException
     */
    ResponseData updateMemberSys(MembersSysModel membersSysModel) throws MemberException;

    /**
     * 根据会员信息生成会员卡号
     *
     * @param memberInfoModel
     * @return
     */
    String produceCarNo(MemberInfoModel memberInfoModel);

    /**
     * 保存会员卡体系
     *
     * @param membersSysModel
     * @param currentUser
     * @return
     */
    ResponseData saveMemberSys(MembersSysModel membersSysModel, SysAccountPO currentUser);


    /**
     * 保存智慧门店会员体系
     */
    ResponseData<String> saveOrUpdateTaoBaoMemberSys(TaoBaoMemberSysRequestVo taoBao,Optional<SysAccountPO> optional);

    /**
     * 查询授权状态
     * @return
     */
    ResponseData<Integer> queryAuthState(Long brandId);


    /**
     * 查询会员卡体系详情
     * @param sysCompanyId
     * @param brandId
     * @return
     */
    ResponseData<MembersSysVo> queryMemberSysInfo(long sysCompanyId, long brandId);


    /**
     * 是否达到可以修改默认服务门店的最低条件
     * @param orderStoreId
     * @param orderStoreOfflineCode
     * @param sysCompanyId
     * @param brandId
     * @param memberCode
     * @return
     */
    boolean canUpdateServiceStore(Long orderStoreId,String orderStoreOfflineCode, Long sysCompanyId, Long brandId,String memberCode);

    /**
     * 查询会员卡体系是否开启默认服务门店变更开关
     * @param sysCompanyId
     * @param brandId
     * @return
     */
    boolean isEnableChangeMbrStore(long sysCompanyId, long brandId);

    /**
     * 查询会员所属服务门店是否是会员卡体系的默认虚拟门店
     * @param memberCode
     * @param serviceStoreId
     * @param sysCompanyId
     * @param brandId
     * @return
     */
    boolean isDefaultServiceStore(String memberCode, Long serviceStoreId, Long sysCompanyId, Long brandId);
}
